@@ -6,6 +6,8 @@
 #include "compat/hdf5.h"
 #include "compat/mumps.h"
 #include "compat/hypre.h"
+#include "compat/viennacl.h"
+#include "compat/cuda.h"
 #include "compat/tao.h"
 
 #endif/*PETSC4PY_COMPAT_H*/
